# Size


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**is_unsupervised** | **bool** |  | [readonly] 
**managed_by** | **str** |  | 
**role** | **int** |  | 
**total_size** | **int, none_type** |  | [readonly] 
**smart_data_size** | **int, none_type** |  | [readonly] 
**total_size_available** | **int, none_type** |  | [readonly] 
**smart_data_size_available** | **int, none_type** |  | [readonly] 
**remaining_total_size** | **int, none_type** |  | [readonly] 
**remaining_smart_data_size** | **int, none_type** |  | [readonly] 
**remaining_total_size_percent** | **int, none_type** |  | [readonly] 
**remaining_smart_data_size_percent** | **int, none_type** |  | [readonly] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


